@@ -1,5 +1,5 @@
-#ifndef _ALLELE_PARSER_H
-#define _ALLELE_PARSER_H
+#ifndef FREEBAYES_ALLELEPARSER_H
+#define FREEBAYES_ALLELEPARSER_H
 
 #include <iostream>
 #include <fstream>
@@ -14,6 +14,7 @@
 #include <ctype.h>
 #include <cmath>
 #include "split.h"
+#include <list> // XXX workaround for a missing include in vcflib's join.h
 #include "join.h"
 
 #include "BedReader.h"
@@ -21,7 +22,7 @@
 #include "Utility.h"
 #include "Allele.h"
 #include "Sample.h"
-#include "Fasta.h"
+#include "FBFasta.h"
 #include "TryCatch.h"
 
 #include "Genotype.h"
@@ -141,7 +142,7 @@ public:
     CNVMap sampleCNV;
 
     // reference
-    FastaReference reference;
+    FB::FastaReference reference;
     vector<string> referenceSequenceNames;
     map<int, string> referenceIDToName;
     string referenceSampleName;
