@@ -1,5 +1,5 @@
-#ifndef SEGFAULTHANDLER_H
-#define SEGFAULTHANDLER_H
+#ifndef FREEBAYES_SEGFAULTHANDLER_H
+#define FREEBAYES_SEGFAULTHANDLER_H
 
 #include <stdio.h>
 #ifndef __CYGWIN__
